@@ -450,6 +450,11 @@ public enum PGProperty {
       "Password to use when authenticating.",
       false),
 
+  /**
+   * Algorithm for the PEM key.
+   */
+  PEM_KEY_ALGORITHM("pemKeyAlgorithm", "RSA", "Algorithm of the PEM key"),
+
   /**
    * Database name to connect to (may be specified directly in the JDBC URL).
    */
@@ -529,6 +534,14 @@ public enum PGProperty {
       false,
       new String[]{"3"}),
 
+  /**
+   * Parameter for {@link java.sql.Statement#getQueryTimeout()}. A value of {@code 0} means no timeout.
+   */
+  QUERY_TIMEOUT(
+      "queryTimeout",
+      "0",
+      "The timeout value in seconds that the driver will wait for a query to execute."),
+
   /**
    * Quote returning columns.
    * There are some ORM's that quote everything, including returning columns
