@@ -48,7 +48,7 @@ public abstract class QueryExecutorBase implements QueryExecutor {
   protected final QueryExecutorCloseAction closeAction;
   private /* @MonotonicNonNull */ String serverVersion;
   private int serverVersionNum;
-  private TransactionState transactionState = TransactionState.IDLE;
+  private volatile TransactionState transactionState = TransactionState.IDLE;
   private final boolean reWriteBatchedInserts;
   private final boolean columnSanitiserDisabled;
   private final EscapeSyntaxCallMode escapeSyntaxCallMode;
@@ -59,7 +59,7 @@ public abstract class QueryExecutorBase implements QueryExecutor {
   protected final boolean logServerErrorDetail;
 
   // default value for server versions that don't report standard_conforming_strings
-  private boolean standardConformingStrings;
+  private volatile boolean standardConformingStrings;
 
   private /* @Nullable */ SQLWarning warnings;
   private final ArrayList<PGNotification> notifications = new ArrayList<>();
@@ -292,16 +292,12 @@ public abstract class QueryExecutorBase implements QueryExecutor {
   }
 
   public void setStandardConformingStrings(boolean value) {
-    try (ResourceLock ignore = lock.obtain()) {
-      standardConformingStrings = value;
-    }
+    standardConformingStrings = value;
   }
 
   @Override
   public boolean getStandardConformingStrings() {
-    try (ResourceLock ignore = lock.obtain()) {
-      return standardConformingStrings;
-    }
+    return standardConformingStrings;
   }
 
   @Override
@@ -311,9 +307,7 @@ public abstract class QueryExecutorBase implements QueryExecutor {
 
   @Override
   public TransactionState getTransactionState() {
-    try (ResourceLock ignore = lock.obtain()) {
-      return transactionState;
-    }
+    return transactionState;
   }
 
   public void setEncoding(Encoding encoding) throws IOException {
