@@ -575,6 +575,22 @@ public abstract class BaseDataSource implements CommonDataSource, Referenceable
     return PGProperty.DEFAULT_ROW_FETCH_SIZE.getIntNoCheck(properties);
   }
 
+  /**
+   * @param seconds default query timeout
+   * @see PGProperty#QUERY_TIMEOUT
+   */
+  public void setQueryTimeout(int seconds) {
+    PGProperty.QUERY_TIMEOUT.set(properties, seconds);
+  }
+
+  /**
+   * @return default query timeout
+   * @see PGProperty#QUERY_TIMEOUT
+   */
+  public int getQueryTimeout() {
+    return PGProperty.QUERY_TIMEOUT.getIntNoCheck(properties);
+  }
+
   /**
    * @param unknownLength unknown length
    * @see PGProperty#UNKNOWN_LENGTH
@@ -1817,6 +1833,14 @@ public abstract class BaseDataSource implements CommonDataSource, Referenceable
     PGProperty.XML_FACTORY_FACTORY.set(properties, xmlFactoryFactory);
   }
 
+  public /* @Nullable */ String getPemKeyAlgorithm() {
+    return PGProperty.PEM_KEY_ALGORITHM.getOrDefault(properties);
+  }
+
+  public void setPemKeyAlgorithm(String algorithm) {
+    PGProperty.PEM_KEY_ALGORITHM.set(properties, algorithm);
+  }
+
   /*
    * Alias methods below, these are to help with ease-of-use with other database tools / frameworks
    * which expect normal java bean getters / setters to exist for the property names.
@@ -1933,4 +1957,13 @@ public abstract class BaseDataSource implements CommonDataSource, Referenceable
   public boolean isReWriteBatchedInserts() {
     return getReWriteBatchedInserts();
   }
+
+  public void setPemKeyAlgo(String algorithm) {
+    setPemKeyAlgorithm(algorithm);
+  }
+
+  public /* @Nullable */ String getPemKeyAlgo() {
+    return getPemKeyAlgorithm();
+  }
+
 }
