@@ -39,10 +39,12 @@ import org.postgresql.geometric.PGpolygon;
 import org.postgresql.largeobject.LargeObjectManager;
 import org.postgresql.replication.PGReplicationConnection;
 import org.postgresql.replication.PGReplicationConnectionImpl;
+import org.postgresql.util.ClassUtils;
 import org.postgresql.util.DriverInfo;
 import org.postgresql.util.GT;
 import org.postgresql.util.HostSpec;
 import org.postgresql.util.LazyCleaner;
+import org.postgresql.util.LazyCleanerImpl;
 import org.postgresql.util.LruCache;
 import org.postgresql.util.PGBinaryObject;
 import org.postgresql.util.PGInterval;
@@ -184,6 +186,13 @@ public class PgConnection implements BaseConnection {
    */
   protected int defaultFetchSize;
 
+  /**
+   * Query timeout for statement.
+   *
+   * @see PGProperty#QUERY_TIMEOUT
+   */
+  protected int queryTimeout;
+
   // Default forcebinary option.
   protected boolean forcebinary;
 
@@ -270,6 +279,8 @@ public class PgConnection implements BaseConnection {
 
     setDefaultFetchSize(PGProperty.DEFAULT_ROW_FETCH_SIZE.getInt(info));
 
+    setQueryTimeout(PGProperty.QUERY_TIMEOUT.getInt(info));
+
     setPrepareThreshold(PGProperty.PREPARE_THRESHOLD.getInt(info));
     if (prepareThreshold == -1) {
       setForceBinary(true);
@@ -389,7 +400,7 @@ public class PgConnection implements BaseConnection {
     replicationConnection = PGProperty.REPLICATION.getOrDefault(info) != null;
 
     xmlFactoryFactoryClass = PGProperty.XML_FACTORY_FACTORY.getOrDefault(info);
-    cleanable = LazyCleaner.getInstance().register(leakHandle, finalizeAction);
+    cleanable = LazyCleanerImpl.getInstance().register(leakHandle, finalizeAction);
   }
 
   private static ReadOnlyBehavior getReadOnlyBehavior(/* @Nullable */ String property) {
@@ -795,7 +806,7 @@ public class PgConnection implements BaseConnection {
   @Deprecated
   public void addDataType(String type, String name) {
     try {
-      addDataType(type, Class.forName(name).asSubclass(PGobject.class));
+      addDataType(type, ClassUtils.forName(name, PGobject.class, getClass().getClassLoader()));
     } catch (Exception e) {
       throw new RuntimeException("Cannot register new type " + type, e);
     }
@@ -842,7 +853,7 @@ public class PgConnection implements BaseConnection {
         Class<?> klass;
 
         try {
-          klass = Class.forName(className);
+          klass = ClassUtils.forName(className, PGobject.class, getClass().getClassLoader());
         } catch (ClassNotFoundException cnfe) {
           throw new PSQLException(
               GT.tr("Unable to load the class {0} responsible for the datatype {1}",
@@ -1272,6 +1283,22 @@ public class PgConnection implements BaseConnection {
     return defaultFetchSize;
   }
 
+  @Override
+  public void setQueryTimeout(int seconds) throws SQLException {
+    if (seconds < 0) {
+      throw new PSQLException(GT.tr("Query timeout must be a value greater than or equal to 0."),
+          PSQLState.INVALID_PARAMETER_VALUE);
+    }
+
+    this.queryTimeout = seconds;
+    LOGGER.log(Level.FINE, "  setQueryTimeout = {0}", seconds);
+  }
+
+  @Override
+  public int getQueryTimeout() {
+    return queryTimeout;
+  }
+
   @Override
   public void setPrepareThreshold(int newThreshold) {
     this.prepareThreshold = newThreshold;
@@ -1958,19 +1985,14 @@ public class PgConnection implements BaseConnection {
     } else if ("LEGACY_INSECURE".equals(xmlFactoryFactoryClass)) {
       xmlFactoryFactory = LegacyInsecurePGXmlFactoryFactory.INSTANCE;
     } else {
-      Class<?> clazz;
+      Class<? extends PGXmlFactoryFactory> clazz;
       try {
-        clazz = Class.forName(xmlFactoryFactoryClass);
+        clazz = ClassUtils.forName(xmlFactoryFactoryClass, PGXmlFactoryFactory.class, getClass().getClassLoader());
       } catch (ClassNotFoundException ex) {
         throw new PSQLException(
             GT.tr("Could not instantiate xmlFactoryFactory: {0}", xmlFactoryFactoryClass),
             PSQLState.INVALID_PARAMETER_VALUE, ex);
       }
-      if (!PGXmlFactoryFactory.class.isAssignableFrom(clazz)) {
-        throw new PSQLException(
-            GT.tr("Connection property xmlFactoryFactory must implement PGXmlFactoryFactory: {0}", xmlFactoryFactoryClass),
-            PSQLState.INVALID_PARAMETER_VALUE);
-      }
       try {
         xmlFactoryFactory = clazz.asSubclass(PGXmlFactoryFactory.class)
             .getDeclaredConstructor()
