@@ -47,7 +47,7 @@ public class ObjectFactory {
           InvocationTargetException {
     /* @Nullable */ Object[] args = {info};
     Constructor<? extends T> ctor = null;
-    Class<? extends T> cls = Class.forName(classname).asSubclass(expectedClass);
+    Class<? extends T> cls = ClassUtils.forName(classname, expectedClass, ObjectFactory.class.getClassLoader());
     try {
       ctor = cls.getConstructor(Properties.class);
     } catch (NoSuchMethodException ignored) {
