@@ -26,11 +26,12 @@ public class PGXADataSourceFactory extends PGObjectFactory {
    * "JDBC2 Enterprise" edition build which doesn't include PGXADataSource.
    */
 
+  @Override
   public /* @Nullable */ Object getObjectInstance(Object obj, Name name, Context nameCtx,
       Hashtable<?, ?> environment) throws Exception {
     Reference ref = (Reference) obj;
     String className = ref.getClassName();
-    if (className.equals("org.postgresql.xa.PGXADataSource")) {
+    if ("org.postgresql.xa.PGXADataSource".equals(className)) {
       return loadXADataSource(ref);
     } else {
       return null;
