@@ -5,23 +5,16 @@
 
 package org.postgresql.core;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+
 import org.postgresql.util.PSQLException;
 
-import org.junit.Assert;
-import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.Parameterized;
+import org.junit.jupiter.params.ParameterizedTest;
+import org.junit.jupiter.params.provider.MethodSource;
 
 import java.util.Arrays;
 
-@RunWith(Parameterized.class)
 public class OidToStringTest {
-  @Parameterized.Parameter(0)
-  public int value;
-  @Parameterized.Parameter(1)
-  public String expected;
-
-  @Parameterized.Parameters(name = "expected={1}, value={0}")
   public static Iterable<Object[]> data() {
     return Arrays.asList(new Object[][]{
         {142, "XML"},
@@ -30,8 +23,9 @@ public class OidToStringTest {
     });
   }
 
-  @Test
-  public void run() throws PSQLException {
-    Assert.assertEquals(expected, Oid.toString(value));
+  @MethodSource("data")
+  @ParameterizedTest
+  void run(int value, String expected) throws PSQLException {
+    assertEquals(expected, Oid.toString(value));
   }
 }
