@@ -1003,6 +1003,22 @@ public abstract class AbstractArraysTest<A> {
       throw new UnsupportedOperationException();
     }
 
+    /**
+     * {@inheritDoc}
+     */
+    @Override
+    public void setQueryTimeout(int seconds) throws SQLException {
+      throw new UnsupportedOperationException();
+    }
+
+    /**
+     * {@inheritDoc}
+     */
+    @Override
+    public int getQueryTimeout() {
+      throw new UnsupportedOperationException();
+    }
+
     /**
      * {@inheritDoc}
      */
