@@ -8,6 +8,7 @@ package org.postgresql.test.jdbc2;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertFalse;
 import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.postgresql.jdbc.TimestampUtils.createProlepticGregorianCalendar;
 
 import org.postgresql.PGProperty;
 import org.postgresql.test.TestUtil;
@@ -76,10 +77,10 @@ public class TimezoneTest {
     TimeZone tzGMT05 = TimeZone.getTimeZone("GMT-05"); // -0500 always
     TimeZone tzGMT13 = TimeZone.getTimeZone("GMT+13"); // +1000 always
 
-    cUTC = Calendar.getInstance(tzUTC);
-    cGMT03 = Calendar.getInstance(tzGMT03);
-    cGMT05 = Calendar.getInstance(tzGMT05);
-    cGMT13 = Calendar.getInstance(tzGMT13);
+    cUTC = createProlepticGregorianCalendar(tzUTC);
+    cGMT03 = createProlepticGregorianCalendar(tzGMT03);
+    cGMT05 = createProlepticGregorianCalendar(tzGMT05);
+    cGMT13 = createProlepticGregorianCalendar(tzGMT13);
   }
 
   @BeforeEach
@@ -859,9 +860,10 @@ public class TimezoneTest {
     PreparedStatement pstmt =
         con.prepareStatement("SELECT ts, d FROM testtimezone order by seq /*" + timeZone + "*/");
 
-    Calendar expectedTimestamp = Calendar.getInstance();
+    Calendar expectedTimestamp = createProlepticGregorianCalendar(TimeZone.getDefault());
 
     SimpleDateFormat sdf = new SimpleDateFormat(testDateFormat);
+    sdf.setCalendar(expectedTimestamp);
 
     for (int i = 0; i < PREPARE_THRESHOLD; i++) {
       ResultSet rs = pstmt.executeQuery();
@@ -971,4 +973,5 @@ public class TimezoneTest {
     }
     return millis;
   }
+
 }
